==> oscars_mgmnt_clms-0.1.8.dev20240626+89-py3-none-any.whl: oscars_mgmnt_clms/parser/geotiff.py <==
import os
import re
from typing import Tuple

import rasterio

from oscars_mgmnt_clms.file_object import ObjectInfo, FileInfo
from oscars_mgmnt_clms.parser.filename import (
    FilenameParser,
    get_geometry,
    decode_platforms,
    parse_date,
    format_date,
)


class CLMSGlobalParser_GeoTIFF(FilenameParser):
    """Parser used to build GeoJSON metadata from CLMS Global Land products in netCDF format"""

    def __init__(self):
        super().__init__(template="CLMS_GLOBAL.template")

    def specific_treatment(self, product_file_info: ObjectInfo, values: dict):
        self.fix_products(product_file_info)

        # example of supported filenames:
        #   c_gls_LSP300-AMPL-S1_202301010000_GLOBE_OLCI_V1.0.1.tiff
        #   c_gls_LSP300-SOSD-S2_202301010000_GLOBE_OLCI_V1.0.1.tiff
        #   c_gls_NDVI300-NDVI_202404010000_AFRI_OLCI_V2.0.1.tiff
        #   c_gls_LAI300-RMSE-RT0_202404200000_AFRI_OLCI_V1.1.2.tiff
        fn = os.path.abspath(product_file_info.get_product_path())
        file_name = os.path.basename(fn).rpartition(".")[0]
        file_name_parts = file_name.split("_")
        product_type_parts = file_name_parts[2].split("-")

        if len(product_type_parts) == 3:
            _, product_type, product_group = product_type_parts
            values["productgroupid"] = product_group
        else:
            _, product_type = product_type_parts

        values["producttype"] = product_type
        version = file_name_parts[-1]
        values["productVersion"] = version

        with rasterio.open(fn) as raster:
            tags = raster.tags()
            values["id"] = file_name

            if raster.descriptions[0]:
                values["title"] = f"{tags['title']} - {', '.join(raster.descriptions)}"
            else:
                _, _, description = (
                    raster.tags(1).get("standard_name", "").partition(" ")
                )
                values["title"] = (
                    f"{tags['title']} - {description}" if description else tags["title"]
                )

            processingCenter = "VITO"
            if "institution" in tags:
                processingCenter = tags["institution"].split(",")[0].upper()
            values["processingCenter"] = (
                processingCenter.replace(" NV", "")
                .replace(" GMBH", "")
                .replace(" ", "_")
            )
            rounding = 7 if "_1km_" in values["parentidentifier"] else 6
            bbox = self.get_bbox(raster, rounding=rounding)
            (
                values["westbbox"],
                values["southbbox"],
                values["eastbbox"],
                values["northbbox"],
            ) = bbox
            values["geometry"] = get_geometry(bbox)
            values["platforms"] = decode_platforms(tags["platform"])
            if "time_coverage_start" in tags:
                values["beginposition"] = format_date(
                    parse_date(tags["time_coverage_start"])
                )
                values["endposition"] = format_date(
                    parse_date(tags["time_coverage_end"])
                )
            else:
                values["beginposition"] = values["nominaldatetime"]
                values["endposition"] = values["nominaldatetime"]

        values["tileid"] = file_name_parts[-3].replace("GLOBAL", "GLOBE")
        collection_dir = re.match(
            f"clms_global_([\\w.-]+)_{self.filetype}", values["parentidentifier"]
        ).group(1)
        resolution_regex = re.compile("([\\d.]+)(m|km)")
        regex_result = resolution_regex.match(collection_dir.split("_")[1])
        if regex_result:
            factor = 1000 if regex_result.group(2)[0] == "k" else 1
            values["resolution"] = int(float(regex_result.group(1)) * factor)
        else:
            values["resolution"] = None
        values["conformsto"] = "https://www.opengis.net/def/crs/EPSG/0/4326"

        return values["id"]

    def get_bbox(
        self, raster: rasterio.DatasetReader, rounding: int
    ) -> Tuple[float, float, float, float]:
        bbox = tuple(map(lambda c: round(c, rounding), raster.bounds))
        return bbox

    @property
    def filetype(self) -> str:
        return "geotiff"

    @property
    def mimetype(self) -> str:
        return "image/tiff"

    def get_file_title(self, info: FileInfo) -> str:
        title = os.path.basename(info.name).split("_")[2].split("-")[1]
        return title

==> oscars_mgmnt_clms-0.1.9.dev20240710+112-py3-none-any.whl: oscars_mgmnt_clms/parser/geotiff.py <==
import os
import re
from typing import Tuple

import rasterio

from oscars_mgmnt_clms.file_object import ObjectInfo
from oscars_mgmnt_clms.parser.filename import (
    FilenameParser,
    get_geometry,
    decode_platforms,
    parse_date,
    format_date,
)


class CLMSGlobalParser_GeoTIFF(FilenameParser):
    """Parser used to build GeoJSON metadata from CLMS Global Land products in netCDF format"""

    def __init__(self):
        super().__init__(template="CLMS_GLOBAL.template")

    def specific_treatment(self, product_file_info: ObjectInfo, values: dict):
        self.fix_products(product_file_info)

        # example of supported filenames:
        #   c_gls_LSP300-AMPL-S1_202301010000_GLOBE_OLCI_V1.0.1.tiff
        #   c_gls_LSP300-SOSD-S2_202301010000_GLOBE_OLCI_V1.0.1.tiff
        #   c_gls_NDVI300-NDVI_202404010000_AFRI_OLCI_V2.0.1.tiff
        #   c_gls_LAI300-RMSE-RT0_202404200000_AFRI_OLCI_V1.1.2.tiff
        fn = os.path.abspath(product_file_info.get_product_path())
        file_name = os.path.basename(fn).rpartition(".")[0]
        file_name_parts = file_name.split("_")
        product_type_parts = file_name_parts[2].split("-")

        values["id"] = file_name
        if len(product_type_parts) == 3:
            _, product_type, product_group = product_type_parts
            values["productgroupid"] = product_group
        else:
            _, product_type = product_type_parts

        values["producttype"] = product_type
        version = file_name_parts[-1]
        values["productVersion"] = version

        self.extract_raster_info(fn, values)

        values["tileid"] = file_name_parts[-3].replace("GLOBAL", "GLOBE")
        collection_dir = re.match(
            f"clms_global_([\\w.-]+)_{self.filetype}", values["parentidentifier"]
        ).group(1)
        resolution_regex = re.compile("([\\d.]+)(m|km)")
        regex_result = resolution_regex.match(collection_dir.split("_")[1])
        if regex_result:
            factor = 1000 if regex_result.group(2)[0] == "k" else 1
            values["resolution"] = int(float(regex_result.group(1)) * factor)
        else:
            values["resolution"] = None
        values["conformsto"] = "https://www.opengis.net/def/crs/EPSG/0/4326"

        return values["id"]

    def extract_raster_info(self, path: str, values: dict):
        with rasterio.open(path) as raster:
            tags = raster.tags()
            values["title"] = self.get_product_title_from_raster(raster, values)

            processingCenter = "VITO"
            if "institution" in tags:
                processingCenter = tags["institution"].split(",")[0].upper()
            values["processingCenter"] = (
                processingCenter.replace(" NV", "")
                .replace(" GMBH", "")
                .replace(" ", "_")
            )
            rounding = 7 if "_1km_" in values["parentidentifier"] else 6
            bbox = self.get_bbox(raster, rounding=rounding)
            (
                values["westbbox"],
                values["southbbox"],
                values["eastbbox"],
                values["northbbox"],
            ) = bbox
            values["geometry"] = get_geometry(bbox)
            values["platforms"] = decode_platforms(tags["platform"])
            if "time_coverage_start" in tags:
                values["beginposition"] = format_date(
                    parse_date(tags["time_coverage_start"])
                )
                values["endposition"] = format_date(
                    parse_date(tags["time_coverage_end"])
                )
            else:
                values["beginposition"] = values["nominaldatetime"]
                values["endposition"] = values["nominaldatetime"]

    def get_product_title_from_raster(self, raster, values: dict) -> str:
        """
        Get the product title from the raster properties.

        :param raster: raster object
        :param values: values dictionary
        """
        tags = raster.tags()
        if raster.descriptions[0]:
            return f"{tags['title']} - {', '.join(raster.descriptions)}"
        else:
            _, _, description = raster.tags(1).get("standard_name", "").partition(" ")
            return f"{tags['title']} - {description}" if description else tags["title"]

    def get_bbox(
        self, raster: rasterio.DatasetReader, rounding: int
    ) -> Tuple[float, float, float, float]:
        bbox = tuple(map(lambda c: round(c, rounding), raster.bounds))
        return bbox

    @property
    def filetype(self) -> str:
        return "geotiff"

    @property
    def mimetype(self) -> str:
        return "image/tiff"

    def get_file_title(self, filename: str) -> str:
        title = os.path.basename(filename).split("_")[2].split("-")[1]
        return title
